==> eea.design-10.1.zip: eea.design-10.1/eea/design/skins/eeadesign_js/promotion_gallery.js <==
/**
 * @version		2.0
 * @package		jquery
 * @subpackage	lofslidernews
 * @copyright	Copyright (C) JAN 2010 LandOfCoder.com <@emai:landofcoder@gmail.com>. All rights reserved.
 * @website     http://landofcoder.com
 * @license		This plugin is dual-licensed under the GNU General Public License and the MIT License

 * @version		2.1 cleanup by ichim-david
 */

(function($) {
    $.fn.lofJSlider = function(settings) {
        return this.each(function() {
            return new $.lofSlider(this, settings);
        });
    };
    $.lofSlider = function(obj, settings) {
        this.settings = {
            direction: '',
            mainItemSelector: 'li',
            navInnerSelector: 'ul',
            navSelector: 'li',
            navigatorEvent: 'click', /* click|mouseenter */
            wrapperSelector: '.sliders-wrap-inner',
            wrapperOuter: '.gallery-slider-wrapper',
            interval: 5000,
            auto: false, // whether to automatic play the slideshow
            maxItemDisplay: 3,
            startItem: 0,
            navPosition: 'vertical', /* values: horizontal|vertical*/
            navigatorHeight: 100,
            navigatorWidth: 310,
            duration: 600,
            navItemsSelector: '.navigator-wrap-inner li',
            navOuterSelector: '.navigator-wrapper',
            isPreloaded: true,
            easing: 'easeInOutQuad',
            pauseOnHover: false,
            galleryControls: "#play-pause",
            galleryPlay: "promo-gallery-play",
            galleryPause: "promo-gallery-pause",
            buttons: null,
            onPlaySlider: function(obj, slider) { obj.wrapper.trigger('promo-gallery:onPlaySlider', { obj: obj, slider: slider }); },
            onComplete: function(slider, index) { slider.trigger('promo-gallery:onComplete', { slider: slider, index: index }); }
        };
        $.extend(this.settings, settings || {});
        this.nextNo = null;
        this.previousNo = null;
        this.maxWidth = this.settings.mainWidth || "100%";

        this.wrapper = $(obj).find(this.settings.wrapperSelector);
        var wrapOuter = $('<div class="gallery-slider-wrapper"></div>').width(this.maxWidth);
        this.wrapper.wrap(wrapOuter);

        this.slides = this.wrapper.find(this.settings.mainItemSelector);
        if (!this.wrapper.length || !this.slides.length) { return; }
        // set width of wrapper
        if (this.settings.maxItemDisplay > this.slides.length) {
            this.settings.maxItemDisplay = this.slides.length;
        }
        this.currentNo = isNaN(this.settings.startItem) || this.settings.startItem > this.slides.length ? 0 : this.settings.startItem;
        this.navigatorOuter = $(obj).find(this.settings.navOuterSelector);
        this.navigatorItems = $(obj).find(this.settings.navItemsSelector);
        this.navigatorInner = this.navigatorOuter.find(this.settings.navInnerSelector);
        // use automatic calculate width of navigator

        if (this.settings.navigatorHeight === null || this.settings.navigatorWidth === null) {
            this.settings.navigatorHeight = this.navigatorItems.eq(0).outerWidth(true);
            this.settings.navigatorWidth = this.navigatorItems.eq(0).outerHeight(true);

        }
        if (this.settings.navPosition === 'horizontal') {
            this.navigatorInner.width(this.slides.length * this.settings.navigatorWidth);
            this.navigatorOuter.width(this.settings.maxItemDisplay * this.settings.navigatorWidth);
            this.navigatorOuter.height(this.settings.navigatorHeight);

        } else {
            this.navigatorInner.height(this.slides.length * this.settings.navigatorHeight);

            this.navigatorOuter.height(this.settings.maxItemDisplay * this.settings.navigatorHeight);
            this.navigatorOuter.width(this.settings.navigatorWidth);
        }
        this.slides.width(this.settings.mainWidth);
        this.navigratorStep = this.__getPositionMode(this.settings.navPosition);
        this.directionMode = this.__getDirectionMode();

        if (this.settings.direction === 'opacity') {
            this.wrapper.addClass('lof-opacity');
            $(this.slides).css({
                'opacity': 0,
                'z-index': 1
            }).eq(this.currentNo).css({
                    'opacity': 1,
                    'z-index': 3
                });
        } else {
            this.wrapper.css({
                'left': '-' + this.currentNo * this.maxSize + 'px',
                'width': (this.maxWidth) * this.slides.length
            });
        }

        if (this.settings.isPreloaded) {
            this.preLoadImage(this.onComplete);
        } else {
            this.onComplete();
        }

        var $buttonControl = $(this.settings.galleryControls, obj);
        if (this.settings.auto) {
            $buttonControl.addClass(this.settings.galleryPause);
        } else {
            $buttonControl.addClass(this.settings.galleryPlay);
        }
        var self = this;

        if (this.settings.pauseOnHover) {
            $(obj).hover(function() {
                self.stop();
            }, function() {
                if (self.settings.auto) {
                    self.play(1, 'next', true);
                }
            });

        }

        $buttonControl.click(function(e) {
            if ($buttonControl.hasClass(self.settings.galleryPlay)) {
                self.settings.auto = true;
                self.play(1, 'next', true);
                $buttonControl.removeClass(self.settings.galleryPlay).addClass(self.settings.galleryPause);
            } else {
                self.settings.auto = false;
                self.stop();
                $buttonControl.addClass(self.settings.galleryPlay).removeClass(self.settings.galleryPause);
            }
            e.preventDefault();
        });
    };
    $.lofSlider.fn = $.lofSlider.prototype;
    $.lofSlider.fn.extend = $.lofSlider.extend = $.extend;

    $.lofSlider.fn.extend({

        startUp: function(obj, wrapper) {
            var self = this;

            this.navigatorItems.each(function(index, item) {
                $(item).bind(self.settings.navigatorEvent, function() {
                    self.jumping(index, true);
                    self.setNavActive(index, item);
                });
                $(item).css({
                    'height': self.settings.navigatorHeight,
                    'width': self.settings.navigatorWidth
                });
            });
            this.setNavActive(this.currentNo);
            this.settings.onComplete(this.slides.eq(this.currentNo), this.currentNo);
            if (this.settings.buttons && typeof(this.settings.buttons) === "object") {
                this.registerButtonsControl('click', this.settings.buttons, this);

            }
            if (this.settings.auto) { this.play(this.settings.interval, 'next', true); }

            return this;
        },
        onComplete: function() {
            setTimeout(function() {
                $('.preload').fadeOut(900, function() {
                    $('.preload').remove();
                });
            }, 400);
            this.startUp();
        },
        preLoadImage: function(callback) {
            var self = this;
            var images = this.wrapper.find('img');

            var count = 0;
            images.each(function(index, image) {
                if (!image.complete) {
                    image.onload = function() {
                        count++;
                        if (count >= images.length) {
                            self.onComplete();
                        }
                    };
                    image.onerror = function() {
                        count++;
                        if (count >= images.length) {
                            self.onComplete();
                        }
                    };
                } else {
                    count++;
                    if (count >= images.length) {
                        self.onComplete();
                    }
                }
            });
        },
        navigationAnimate: function(currentIndex) {
            if (currentIndex <= this.settings.startItem || currentIndex - this.settings.startItem >= this.settings.maxItemDisplay - 1) {
                this.settings.startItem = currentIndex - this.settings.maxItemDisplay + 2;
                if (this.settings.startItem < 0) { this.settings.startItem = 0; }
                if (this.settings.startItem > this.slides.length - this.settings.maxItemDisplay) {
                    this.settings.startItem = this.slides.length - this.settings.maxItemDisplay;
                }
            }

            this.navigatorInner.stop().animate(eval('({' + this.navigratorStep[0] + ':-' + this.settings.startItem * this.navigratorStep[1] + '})'), {
                duration: 500,
                easing: 'easeInOutQuad'
            });
        },
        setNavActive: function(index, item) {
            if ((this.navigatorItems)) {
                this.navigatorItems.removeClass('active');
                $(this.navigatorItems.get(index)).addClass('active');
                this.navigationAnimate(this.currentNo);
            }
        },
        __getPositionMode: function(position) {
            if (position === 'horizontal') {
                return ['left', this.settings.navigatorWidth];
            }
            return ['top', this.settings.navigatorHeight];
        },
        __getDirectionMode: function() {
            switch (this.settings.direction) {
                case 'opacity':
                    this.maxSize = 0;
                    return ['opacity', 'opacity'];
                default:
                    this.maxSize = this.maxWidth;
                    return ['left', 'width'];
            }
        },
        registerButtonsControl: function(eventHandler, objects, self) {
            function next(e) {
                self.next(true);
                e.preventDefault();
            }
            function previous(e) {
                self.previous(true);
                e.preventDefault();
            }
            for (var action in objects) {
                if (objects.hasOwnProperty(action)) {
                    switch (action.toString()) {
                        case 'next':
                            objects[action].click(next);
                            break;
                        case 'previous':
                            objects[action].click(previous);
                            break;
                    }
                }
            }
            return this;
        },
        onProcessing: function(manual, start, end) {
            this.previousNo = this.currentNo + (this.currentNo > 0 ? -1 : this.slides.length - 1);
            this.nextNo = this.currentNo + (this.currentNo < this.slides.length - 1 ? 1 : 1 - this.slides.length);
            return this;
        },
        finishFx: function(manual) {
            if (manual) { this.stop(); }
            if (manual && this.settings.auto) {
                this.play(this.settings.interval, 'next', true);
            }
            this.setNavActive(this.currentNo);
            this.settings.onPlaySlider(this, $(this.slides).eq(this.currentNo));
        },
        getObjectDirection: function(start, end) {
            return eval("({'" + this.directionMode[0] + "':-" + (this.currentNo * start) + "})");
        },
        fxStart: function(index, obj, currentObj) {
            var s = this;
            if (this.settings.direction === 'opacity') {

                $(this.slides).stop().animate({
                    opacity: 0
                }, {
                    duration: this.settings.duration,
                    easing: this.settings.easing,
                    complete: function() {
                        s.slides.css("z-index", "1");
                        s.slides.eq(index).css("z-index", "3");
                    }
                });
                $(this.slides).eq(index).stop().animate({
                    opacity: 1
                }, {
                    duration: this.settings.duration,
                    easing: this.settings.easing,
                    complete: function() {
                        s.settings.onComplete($(s.slides).eq(index), index);
                    }
                });
            } else {
                this.wrapper.stop().animate(obj, {
                    duration: this.settings.duration,
                    easing: this.settings.easing,
                    complete: function() {
                        s.settings.onComplete($(s.slides).eq(index), index);
                    }
                });
            }
            return this;
        },
        jumping: function(no, manual) {
            this.stop();
            if (this.currentNo === no) { return; }
            var obj = eval("({'" + this.directionMode[0] + "':-" + (this.maxSize * no) + "})");
            this.onProcessing(null, manual, 0, this.maxSize)
                .fxStart(no, obj, this)
                .finishFx(manual);
            this.currentNo = no;
        },
        next: function(manual, item) {

            this.currentNo += (this.currentNo < this.slides.length - 1) ? 1 : (1 - this.slides.length);
            this.onProcessing(item, manual, 0, this.maxSize)
                .fxStart(this.currentNo, this.getObjectDirection(this.maxSize), this)
                .finishFx(manual);
        },
        previous: function(manual, item) {
            this.currentNo += this.currentNo > 0 ? -1 : this.slides.length - 1;
            this.onProcessing(item, manual)
                .fxStart(this.currentNo, this.getObjectDirection(this.maxSize), this)
                .finishFx(manual);
        },
        play: function(delay, direction, wait) {
            this.stop();
            if (!wait) {
                this[direction](false);
            }
            var self = this;
            this.isRun = setTimeout(function() {
                self[direction](true);
            }, delay);
        },
        stop: function() {
            if (this.isRun === null) { return; }
            clearTimeout(this.isRun);
            this.isRun = null;
        }
    });
})(jQuery);

==> eea.design-11.4.zip: eea.design-11.4/eea/design/skins/eeadesign_js/promotion_gallery.js <==
/**
 * @version		2.0
 * @package		jquery
 * @subpackage	lofslidernews
 * @copyright	Copyright (C) JAN 2010 LandOfCoder.com <@emai:landofcoder@gmail.com>. All rights reserved.
 * @website     http://landofcoder.com
 * @license		This plugin is dual-licensed under the GNU General Public License and the MIT License

 * @version		2.1 cleanup by ichim-david
 */

(function($) {
    $.fn.lofJSlider = function(settings) {
        return this.each(function() {
            return new $.lofSlider(this, settings);
        });
    };
    $.lofSlider = function(obj, settings) {
        this.settings = {
            direction: '',
            mainItemSelector: 'li',
            navInnerSelector: 'ul',
            navSelector: 'li',
            navigatorEvent: 'click', /* click|mouseenter */
            wrapperSelector: '.sliders-wrap-inner',
            wrapperOuter: '.gallery-slider-wrapper',
            interval: 5000,
            auto: false, // whether to automatic play the slideshow
            maxItemDisplay: 3,
            startItem: 0,
            navPosition: 'vertical', /* values: horizontal|vertical*/
            navigatorHeight: 100,
            navigatorWidth: 310,
            duration: 600,
            navItemsSelector: '.navigator-wrap-inner li',
            navOuterSelector: '.navigator-wrapper',
            isPreloaded: true,
            easing: 'easeInOutQuad',
            pauseOnHover: false,
            galleryControls: "#play-pause",
            galleryPlay: "promo-gallery-play",
            galleryPause: "promo-gallery-pause",
            buttons: null,
            onPlaySlider: function(obj, slider) { obj.wrapper.trigger('promo-gallery:onPlaySlider', { obj: obj, slider: slider }); },
            onComplete: function(slider, index) { slider.trigger('promo-gallery:onComplete', { slider: slider, index: index }); }
        };
        $.extend(this.settings, settings || {});
        this.nextNo = null;
        this.previousNo = null;
        this.maxWidth = this.settings.mainWidth || "100%";

        this.wrapper = $(obj).find(this.settings.wrapperSelector);
        var wrapOuter = $('<div class="gallery-slider-wrapper"></div>').width(this.maxWidth);
        this.wrapper.wrap(wrapOuter);

        this.slides = this.wrapper.find(this.settings.mainItemSelector);
        if (!this.wrapper.length || !this.slides.length) { return; }
        // set width of wrapper
        if (this.settings.maxItemDisplay > this.slides.length) {
            this.settings.maxItemDisplay = this.slides.length;
        }
        this.currentNo = isNaN(this.settings.startItem) || this.settings.startItem > this.slides.length ? 0 : this.settings.startItem;
        this.navigatorOuter = $(obj).find(this.settings.navOuterSelector);
        this.navigatorItems = $(obj).find(this.settings.navItemsSelector);
        this.navigatorInner = this.navigatorOuter.find(this.settings.navInnerSelector);
        // use automatic calculate width of navigator

        if (this.settings.navigatorHeight === null || this.settings.navigatorWidth === null) {
            this.settings.navigatorHeight = this.navigatorItems.eq(0).outerWidth(true);
            this.settings.navigatorWidth = this.navigatorItems.eq(0).outerHeight(true);

        }
        if (this.settings.navPosition === 'horizontal') {
            this.navigatorInner.width(this.slides.length * this.settings.navigatorWidth);
            this.navigatorOuter.width(this.settings.maxItemDisplay * this.settings.navigatorWidth);
            this.navigatorOuter.height(this.settings.navigatorHeight);

        } else {
            this.navigatorInner.height(this.slides.length * this.settings.navigatorHeight);

            this.navigatorOuter.height(this.settings.maxItemDisplay * this.settings.navigatorHeight);
            this.navigatorOuter.width(this.settings.navigatorWidth);
        }
        this.slides.width(this.settings.mainWidth);
        this.navigratorStep = this.__getPositionMode(this.settings.navPosition);
        this.directionMode = this.__getDirectionMode();

        if (this.settings.direction === 'opacity') {
            this.wrapper.addClass('lof-opacity');
            $(this.slides).css({
                'opacity': 0,
                'z-index': 1
            }).eq(this.currentNo).css({
                    'opacity': 1,
                    'z-index': 3
                });
        } else {
            this.wrapper.css({
                'left': '-' + this.currentNo * this.maxSize + 'px',
                'width': (this.maxWidth) * this.slides.length
            });
        }

        if (this.settings.isPreloaded) {
            this.preLoadImage(this.onComplete);
        } else {
            this.onComplete();
        }

        var $buttonControl = $(this.settings.galleryControls, obj);
        if (this.settings.auto) {
            $buttonControl.addClass(this.settings.galleryPause);
        } else {
            $buttonControl.addClass(this.settings.galleryPlay);
        }
        var self = this;

        if (this.settings.pauseOnHover) {
            $(obj).hover(function() {
                self.stop();
            }, function() {
                if (self.settings.auto) {
                    self.play(1, 'next', true);
                }
            });

        }

        $buttonControl.click(function(e) {
            if ($buttonControl.hasClass(self.settings.galleryPlay)) {
                self.settings.auto = true;
                self.play(1, 'next', true);
                $buttonControl.removeClass(self.settings.galleryPlay).addClass(self.settings.galleryPause);
            } else {
                self.settings.auto = false;
                self.stop();
                $buttonControl.addClass(self.settings.galleryPlay).removeClass(self.settings.galleryPause);
            }
            e.preventDefault();
        });
    };
    $.lofSlider.fn = $.lofSlider.prototype;
    $.lofSlider.fn.extend = $.lofSlider.extend = $.extend;

    $.lofSlider.fn.extend({

        startUp: function(obj, wrapper) {
            var self = this;

            this.navigatorItems.each(function(index, item) {
                $(item).bind(self.settings.navigatorEvent, function() {
                    self.jumping(index, true);
                    self.setNavActive(index, item);
                });
                $(item).css({
                    'height': self.settings.navigatorHeight,
                    'width': self.settings.navigatorWidth
                });
            });
            this.setNavActive(this.currentNo);
            this.settings.onComplete(this.slides.eq(this.currentNo), this.currentNo);
            if (this.settings.buttons && typeof(this.settings.buttons) === "object") {
                this.registerButtonsControl('click', this.settings.buttons, this);

            }
            if (this.settings.auto) { this.play(this.settings.interval, 'next', true); }

            return this;
        },
        onComplete: function() {
            setTimeout(function() {
                $('.preload').fadeOut(900, function() {
                    $('.preload').remove();
                });
            }, 400);
            this.startUp();
        },
        preLoadImage: function(callback) {
            var self = this;
            var images = this.wrapper.find('img');

            var count = 0;
            images.each(function(index, image) {
                if (!image.complete) {
                    image.onload = function() {
                        count++;
                        if (count >= images.length) {
                            self.onComplete();
                        }
                    };
                    image.onerror = function() {
                        count++;
                        if (count >= images.length) {
                            self.onComplete();
                        }
                    };
                } else {
                    count++;
                    if (count >= images.length) {
                        self.onComplete();
                    }
                }
            });
        },
        navigationAnimate: function(currentIndex) {
            if (currentIndex <= this.settings.startItem || currentIndex - this.settings.startItem >= this.settings.maxItemDisplay - 1) {
                this.settings.startItem = currentIndex - this.settings.maxItemDisplay + 2;
                if (this.settings.startItem < 0) { this.settings.startItem = 0; }
                if (this.settings.startItem > this.slides.length - this.settings.maxItemDisplay) {
                    this.settings.startItem = this.slides.length - this.settings.maxItemDisplay;
                }
            }

            this.navigatorInner.stop().animate((0,eval)('({' + this.navigratorStep[0] + ':-' + this.settings.startItem * this.navigratorStep[1] + '})'), {
                duration: 500,
                easing: 'easeInOutQuad'
            });
        },
        setNavActive: function(index, item) {
            if ((this.navigatorItems)) {
                this.navigatorItems.removeClass('active');
                $(this.navigatorItems.get(index)).addClass('active');
                this.navigationAnimate(this.currentNo);
            }
        },
        __getPositionMode: function(position) {
            if (position === 'horizontal') {
                return ['left', this.settings.navigatorWidth];
            }
            return ['top', this.settings.navigatorHeight];
        },
        __getDirectionMode: function() {
            switch (this.settings.direction) {
                case 'opacity':
                    this.maxSize = 0;
                    return ['opacity', 'opacity'];
                default:
                    this.maxSize = this.maxWidth;
                    return ['left', 'width'];
            }
        },
        registerButtonsControl: function(eventHandler, objects, self) {
            function next(e) {
                self.next(true);
                e.preventDefault();
            }
            function previous(e) {
                self.previous(true);
                e.preventDefault();
            }
            for (var action in objects) {
                if (objects.hasOwnProperty(action)) {
                    switch (action.toString()) {
                        case 'next':
                            objects[action].click(next);
                            break;
                        case 'previous':
                            objects[action].click(previous);
                            break;
                    }
                }
            }
            return this;
        },
        onProcessing: function(manual, start, end) {
            this.previousNo = this.currentNo + (this.currentNo > 0 ? -1 : this.slides.length - 1);
            this.nextNo = this.currentNo + (this.currentNo < this.slides.length - 1 ? 1 : 1 - this.slides.length);
            return this;
        },
        finishFx: function(manual) {
            if (manual) { this.stop(); }
            if (manual && this.settings.auto) {
                this.play(this.settings.interval, 'next', true);
            }
            this.setNavActive(this.currentNo);
            this.settings.onPlaySlider(this, $(this.slides).eq(this.currentNo));
        },
        getObjectDirection: function(start, end) {
            return (0,eval)("({'" + this.directionMode[0] + "':-" + (this.currentNo * start) + "})");
        },
        fxStart: function(index, obj, currentObj) {
            var s = this;
            if (this.settings.direction === 'opacity') {

                $(this.slides).stop().animate({
                    opacity: 0
                }, {
                    duration: this.settings.duration,
                    easing: this.settings.easing,
                    complete: function() {
                        s.slides.css("z-index", "1");
                        s.slides.eq(index).css("z-index", "3");
                    }
                });
                $(this.slides).eq(index).stop().animate({
                    opacity: 1
                }, {
                    duration: this.settings.duration,
                    easing: this.settings.easing,
                    complete: function() {
                        s.settings.onComplete($(s.slides).eq(index), index);
                    }
                });
            } else {
                this.wrapper.stop().animate(obj, {
                    duration: this.settings.duration,
                    easing: this.settings.easing,
                    complete: function() {
                        s.settings.onComplete($(s.slides).eq(index), index);
                    }
                });
            }
            return this;
        },
        jumping: function(no, manual) {
            this.stop();
            if (this.currentNo === no) { return; }
            var obj = (0,eval)("({'" + this.directionMode[0] + "':-" + (this.maxSize * no) + "})");
            this.onProcessing(null, manual, 0, this.maxSize)
                .fxStart(no, obj, this)
                .finishFx(manual);
            this.currentNo = no;
        },
        next: function(manual, item) {

            this.currentNo += (this.currentNo < this.slides.length - 1) ? 1 : (1 - this.slides.length);
            this.onProcessing(item, manual, 0, this.maxSize)
                .fxStart(this.currentNo, this.getObjectDirection(this.maxSize), this)
                .finishFx(manual);
        },
        previous: function(manual, item) {
            this.currentNo += this.currentNo > 0 ? -1 : this.slides.length - 1;
            this.onProcessing(item, manual)
                .fxStart(this.currentNo, this.getObjectDirection(this.maxSize), this)
                .finishFx(manual);
        },
        play: function(delay, direction, wait) {
            this.stop();
            if (!wait) {
                this[direction](false);
            }
            var self = this;
            this.isRun = setTimeout(function() {
                self[direction](true);
            }, delay);
        },
        stop: function() {
            if (this.isRun === null) { return; }
            clearTimeout(this.isRun);
            this.isRun = null;
        }
    });
})(jQuery);
